`timescale 1 ns/1 ns

localparam  CLK_MHZ    = 100 ;             // Frequency of simulated clock
localparam  CLK_PERIOD = 1000/CLK_MHZ ;   // Period of simulated clock.
localparam  ENDTIME    = 40000 ;          // Number of ns to stop simulation at.

parameter   N = 20 ;

module cordic_tb();
	// Test parameters

	// Signal declarations
	reg                 clk   = 0    ;
	reg        [N-1:0]  angle = 0    ;
	wire       [N-1:0]  sine         ;
	wire       [N-1:0]  cosine       ;
	wire       [N-1:0]  vhdl_sine    ;
	wire       [N-1:0]  vhdl_cosine  ;

	// Instantiate DUT
	cordic DUT (
    .clk          ( clk       ),
    .angle        ( angle     ),
    .sine         ( sine      ),
    .cosine       ( cosine    ) );

	// Instantiate reference VHDL design.
	sin_cos REFD  (
    .clk          ( clk         ),
    .de_in        ( 1'b1        ),
    .angle        ( angle       ),
    .de_out       (             ),
    .sine         ( vhdl_sine   ),
    .cosine       ( vhdl_cosine ) );

initial begin

clk   =     1'b0   ;
angle = 20'h1999a ; 

end
	
// Generate simulated clock.	
	always
	begin
		// main clock
		clk = 1'b1;
		#(CLK_PERIOD/2);	// high for 1*timescale
		
		clk = 1'b0;
		#(CLK_PERIOD/2);	// low for 1*timescale
	end
    

    // Stop simulating after 10000ns.
    always #(ENDTIME)      $stop            ;  // Stop simulation from going on forever

endmodule
